<?php

namespace EmailTunnel;

class Action_ConnectWithMothership extends Abstract_API_Action
{
    public $capability = "install_plugins";
    public $namespace = "email-tunnel/v1";
    public $actionName = "connect-with-mothership";


    /**
     * called from the frontend to connect a remote node
     * it doesn't matter if the node thinks it's connected already or not, this action should still be allowed by an admin
     * once every 15 minutes
     * @param  mixed $args this function doesn't require any arguments - left in for compatibility
     * @return mixed       the response from the mothership
     */
    public function doAction($args = null)
    {
        //die("I dont get it3");

        global $current_user;
        $current_user = \wp_get_current_user();
        $userID = $current_user->ID;
        $userEmail = $current_user->user_email;
        $siteUrl = \get_site_url();

        //This will check if ANY connection attempt has been made by an admin on this site in the last 15 minutes.
        $Connection = ConnectionFinder::get_post_type_by_title('ET MOTHERSHIP CONNECTION ATTEMPT', 'OBJECT', 'etm-connection');

        if($Connection === null){
            return $this->doContactMothership($userEmail, $siteUrl, $this->doCreateConnectionCPT($userID));
        }

        if(Action_ConnectWithMothership::isIt15MinutesOld($Connection->ID)){
            \wp_delete_post($Connection->ID, true);
            return $this->doContactMothership($userEmail, $siteUrl, $this->doCreateConnectionCPT($userID));
        }
        return "ERROR: CONNECTION ATTEMPT ALREADY PENDING";
    }

    /**
     * contacts the "mothership" with the "remote-site-nonce"
     * @param  string $userEmail       i.e. "email@email.com" [!not a userID!]
     * @param  string $remoteSiteUrl   the local URL, i.e. "https://somesite.com"
     * @param  string $remoteSiteNonce the "remote-site-nonce" is a 50 character random string.
     * @return mixed                   the server response from mothership
     */
    public function doContactMothership($userEmail, $remoteSiteUrl, $remoteSiteNonce)
    {
        global $EmailTunnelConstants;
        $motherShipURL = $EmailTunnelConstants->motherShipURL;
        $result = \wp_remote_post("$motherShipURL/wp-json/etm/v1/receive-send-connection-email-request",
            array(
                'method' => 'POST',
                'timeout' => 60,
                'blocking' => true,
                'headers' => array(),
                'body' => array(
                    'user-email' => $userEmail,
                    'remote-site-nonce' => $remoteSiteNonce,
                    'remote-site-url' => $remoteSiteUrl
                ),
            )
        );
        return $result;
    }

    /**
     * creates a "etm-connection" CPT for this remote node, with a remote-site-nonce
     * @param integer $userID the registered admin for the remote node, who is creating the CPT
     * @return string           the "remote-site-nonce" is a 50 character random string.
     */
    public function doCreateConnectionCPT($userID)
    {
        $args = [
            'post_title' => 'ET MOTHERSHIP CONNECTION ATTEMPT',
            'post_type' => 'etm-connection',
            'post_author' => $userID,
            'post_content' => 'A connection attempt is being made on this remote node.',
        ];
        $connectionID = \wp_insert_post($args);
        $RSNonce = GenerateRandomString::generateRandomString(50);
        \update_post_meta($connectionID, 'nonce', $RSNonce);
        return $RSNonce;
    }

    /**
     * Checks if the given post is 15 minutes old or not.
     * @param  int  $postID The ID of the post to check.
     * @return bool         True if the post is 15 minutes old or more, false otherwise.
     */
    public static function isIt15MinutesOld($postID)
    {
        $post = get_post($postID);
        $modifiedTime = strtotime($post->post_modified);
        $currentTime = time();
        $timeDiff = $currentTime - $modifiedTime;
        if ($timeDiff <= 900) {
            return false;
        }
        return true;
    }
}