<?php
namespace EmailTunnel;

class Action_SendCommandToMothership {

    public function doAction($args){
        global $EmailTunnelConstants;

        // Construct the endpoint URL
        $endpoint = $EmailTunnelConstants->motherShipURL . "/wp-json/etm/v1/" . $args['command'];

        // Fetch connection details
        $Connection = ConnectionFinder::fetchSingularPostByTitleAndAuthor("THIS IS A VALIDATED REMOTE NODE", \get_current_user_id(), "etm-connection" );
        $etmNonce = \get_post_meta($Connection->ID, "etm-nonce", true);
        $current_user = \wp_get_current_user();
        $email = $current_user->user_email;

        // Append query parameters to the endpoint URL
        $endpoint .= "?etm-nonce=" . $etmNonce . "&entrance-site-url=" . $args['entrance-site-url'] . "&exit-site-url=" . $args['exit-site-url'] . "&email=" . $email;

        // Set request options
        $options = [
            'body'        => [],
            'headers'     => [
                'Content-Type' => 'application/json',
            ],
            'timeout'     => 60,
            'redirection' => 5,
            'blocking'    => true,
            'httpversion' => '1.0',
            'sslverify'   => false,
            'data_format' => 'body',
        ];

        // Make the remote post request
        $result = \wp_remote_post($endpoint, $options);

        // Check for errors in the response
        if (is_wp_error($result)) {
            error_log('Error in wp_remote_post: ' . $result->get_error_message());
            return $result;
        }

        // Decode the response body
        $statusArray = json_decode(json_decode($result['body']), true);

        // Update local status from the status array
        SetLocalStatusFromStatusArray::doSetStatus($statusArray);

        // Pull pings from specified URLs
        self::doPullPing($args['exit-site-url']);
        self::doPullPing($args['entrance-site-url']);

        return $result;
    }

    private static function doPullPing($remoteSiteURL){
        if($remoteSiteURL === \get_site_url()){
            return;
        }
        $options = [
            'body'        => [],
            'headers'     => [
                'Content-Type' => 'application/json',
            ],
            'timeout'     => 60,
            'redirection' => 5,
            'blocking'    => false,
            'httpversion' => '1.0',
            'sslverify'   => false,
            'data_format' => 'body',
        ];
        $endpoint = $remoteSiteURL . "/?page=email-tunnel";
        \wp_remote_post($endpoint, $options);
        return true;
    }

    public $capability = "activate_plugins";
    public $nameSpace = "email-tunnel/v1";
    public $actionName = "send-command-2-ms";

    private function getNamespace() { return $this->nameSpace; }
    private function getCapability() { return $this->capability; }
    private function getActionName() { return $this->actionName; }
    private function getMethods() { return ['POST', 'GET']; }

    public function doRegisterRoutes(){
        \register_rest_route(
            $this->getNamespace(),
            $this->getActionName(),
            array(
                'methods' => $this->getMethods(),
                'callback' => function () {
                    return $this->doAction($_REQUEST);
                },
                'permission_callback' => function () {
                    return current_user_can($this->getCapability());
                },
                'validate_callback' => function ($args) {
                    return isset($args['exit-site-url']) && filter_var($args['exit-site-url'], FILTER_VALIDATE_URL) &&
                        isset($args['entrance-site-url']) && filter_var($args['entrance-site-url'], FILTER_VALIDATE_URL);
                }
            )
        );
    }
}
