<?php

namespace EmailTunnel;

class Action_ValidateEmailConnectionRequestNonce{

    /**
     * Enables validation through a GET variable
     * @param  string $_GET['etm-activation-nonce'] the activation nonce
     * @return bool                                 true <- return true or die!
     */
    public function enable(){
        if(isset($_GET["etm-activation-nonce"])){
            if(!(is_string($_GET["etm-activation-nonce"]))){
                die("something is wrong. Error code Action_ValidateEmailConnectionRequestNonce 15.");
            }
            if(!(is_user_logged_in())){
                \auth_redirect();
                die("something is wrong. You must be logged in to verify this nonce.");
            }
            $args['userID'] = get_current_user_id();
            $args['nonce'] = sanitize_text_field( $_GET['etm-activation-nonce']);
            $this->doAction($args);
        }
        return true; //<- return true or die!
    }

    /**
     * The main validation script
     * @param array $args['nonce'] the activation nonce
     * @return bool true
     */
    public function doAction($args){
        $Connection = ConnectionFinder::get_post_type_by_title("ET MOTHERSHIP CONNECTION ATTEMPT", "object", "etm-connection");
        if($Connection == null){
            die ( "ERROR: NO PENDING CONNECTION ATTEMPT");
        }else{
            $args['connectionID'] = $Connection->ID;
        }
        if(!($this->doValidateLocally($args))){
            die("ERROR: cannot locally validate");
        }
        if(!($this->doValidateOnMothership($args))){
            die( "ERROR: cannot validate on mothership");
        }
        \wp_reset_postdata();
            $newArgs = [
                    'ID' => $args['connectionID'],
                    'post_title' => 'THIS IS A VALIDATED REMOTE NODE'
            ];
        \wp_update_post($newArgs);
        \update_post_meta($args['connectionID'], 'mothership-nonce', substr($args['nonce'], 50, 50) );
    }

    public function doValidateOnMothership($args){
        $user = \wp_get_current_user();
        if($user == false){
            return false;
        }
        $args['user-email'] = $user->user_email;
        global $EmailTunnelConstants;
        $motherShipURL = $EmailTunnelConstants->motherShipURL;
        $siteName = \get_bloginfo( 'name' );
        $remoteSiteUrl = \get_site_url();

        $data = [
            'user-email'        => $args['user-email'],
            'nonce'             => $args['nonce'],
            'site-name'         => $siteName,
            'remote-site-url'   => $remoteSiteUrl
        ];
        $encodedResult = \wp_remote_post( "$motherShipURL/wp-json/etm/v1/validate-ecrn",
            array(
                'method'      => 'POST',
                'timeout'     => 45,
                'redirection' => 5,
                'httpversion' => '1.0',
                'blocking'    => true,
                'headers'     => array(),
                'body'        => $data,
            )
        );
        $result = json_decode(html_entity_decode($encodedResult['body']), true);

        if ($result['nonce-check'] == 'VALID NONCE'){
            \update_post_meta( $args['connectionID'], 'licence', $result['license']);

            //todo: this should be called the etm-user-nonce:
            \update_post_meta( $args['connectionID'], 'etm-nonce', $result['etm-nonce']);
            return true;
        }else{
            var_dump($result);
            die("ERROR: the nonce check failed");
        }
    }

    public function doValidateLocally($args){
        $givenNonce = $args['nonce'];
        $givenNonce = substr($givenNonce, 0, 50);
        $Connection = ConnectionFinder::get_post_type_by_title("ET MOTHERSHIP CONNECTION ATTEMPT", "OBJECT", "etm-connection");
        if (!(\metadata_exists('post', $Connection->ID, 'nonce'))){
            return false;
        }
        $nonce = \get_post_meta($Connection->ID, 'nonce');
        if(!($nonce[0] == $givenNonce)){
            return false;
        }
         return true;
    }
}