<?php

namespace EmailTunnel;

class SetLocalStatusFromStatusArray {

    /**
     * Process a status array received from the mothership server to set the local site's status within the email tunnel network.
     *
     * The status array provides a snapshot of the network, containing multiple entries where each entry includes:
     * - title: The URL of the site.
     * - status: Indicates if the site is an 'entrance', 'exit', or otherwise.
     * - exit-site: The URL of the exit site if the current site is an entrance.
     * - email-count: (currently not used) Potential future use could include counting emails handled.
     *
     * This method searches for the local site's URL in the status array to determine and set its role in the network (entrance or exit).
     *
     * Example of a status array:
     * [
     *     {'title': 'http://18.191.17.46', 'status': 'entrance', 'exit-site': 'http://3.142.123.30', 'email-count': ''},
     *     {'title': 'http://3.142.123.30', 'status': 'exit', 'exit-site': '', 'email-count': ''}
     * ]
     */

    public static function doSetStatus($statusArray) {
        $siteURL = \get_site_url(); // Retrieve the URL of the current WordPress site
        $ValidatedNode = ConnectionFinder::fetchValidatedNodeConnection();

        foreach ($statusArray as $item) {
            if ($item['title'] == $siteURL) {
                if ($item['status'] === "entrance") {
                    // If the local site's URL matches the 'title' and its status is 'entrance',
                    // set the local site as an entrance and specify its corresponding exit site.
                    SiteStatus::setSiteStatus("entrance", $ValidatedNode->ID);
                    SiteStatus::setSiteExit($item['exit-site']);
                    return;
                }
            }
            if ($item['status'] === "entrance" && $item['exit-site'] === $siteURL) {
                // If the local site's URL matches the 'exit-site' of an entrance site,
                // set the local site as the exit for that entrance.
                SiteStatus::setSiteStatus("exit", $ValidatedNode->ID);
                return;
            }
        }
        // If no matching entry is found, set the site status to 'not connected' indicating it is neither an entrance nor an exit.
        SiteStatus::setSiteStatus("not connected", $ValidatedNode->ID);
    }
}
