import fillConnectionTableWithData from "./fillConnectionTableWithData";

describe('Testing fillConnectionTableWithData', () => {
    beforeEach(() => {
        document.body.innerHTML = `
            <table id="email-tunnel-connection-table" class="wp-list-table widefat fixed striped table-view-list">
                <thead>
                    <tr>
                        <th scope="col" class="manage-column column-primary">Entrance</th>
                        <th scope="col" class="manage-column">Exit</th>
                        <th scope="col" class="manage-column">Emails</th>
                        <th scope="col" class="manage-column">Action</th>
                    </tr>
                </thead>
                <tbody id="email-tunnel-connection-table-body">
                </tbody>
                <tfoot>
                    <tr>
                        <th scope="col" class="manage-column column-primary">Entrance</th>
                        <th scope="col" class="manage-column">Exit</th>
                        <th scope="col" class="manage-column">Emails</th>
                        <th scope="col" class="manage-column">Action</th>
                    </tr>
                </tfoot>
            </table>
        `;
    });

    test('should add rows for multiple "entrance" sites connected to one "exit"', () => {
        const statusArray = [
            { "title": "https://sitea.com", "status": "entrance", "exit-site": "https://siteexit.com", "email-count": "100" },
            { "title": "https://siteb.com", "status": "entrance", "exit-site": "https://siteexit.com", "email-count": "200" },
            { "title": "https://sitec.com", "status": "entrance", "exit-site": "https://siteexit.com", "email-count": "150" },
            { "title": "https://siteexit.com", "status": "exit", "exit-site": "", "email-count": "" }
        ];

        const table = document.getElementById('email-tunnel-connection-table');
        fillConnectionTableWithData(table, statusArray);

        const rows = table.querySelectorAll('tbody tr');
        expect(rows.length).toBe(3); // Three entrances should create three rows

        // Asserting correct data mapping for the first row as example
        expect(rows[0].cells[0].textContent).toContain("https://sitea.com");
        expect(rows[0].cells[1].textContent).toContain("https://siteexit.com");
        expect(rows[0].cells[2].textContent).toContain("100");

        // Assert further as needed for rows[1] and rows[2]
    });

    test('should display "No sites connected." when no "entrance" status is found', () => {
        const statusArray = [
            { "title": "https://onlyexit.com", "status": "exit", "exit-site": "", "email-count": "" }
        ];

        const table = document.getElementById('email-tunnel-connection-table');
        fillConnectionTableWithData(table, statusArray);

        const rows = table.querySelectorAll('tbody tr');
        expect(rows.length).toBe(1); // One row for no connection
        expect(rows[0].cells[0].textContent).toBe("No sites connected.");
    });
});
describe('Testing fillConnectionTableWithData', () => {
    beforeEach(() => {
        document.body.innerHTML = `
            <table id="email-tunnel-connection-table" class="wp-list-table widefat fixed striped table-view-list">
                <thead>
                    <tr>
                        <th scope="col" class="manage-column column-primary">Entrance</th>
                        <th scope="col" class="manage-column">Exit</th>
                        <th scope="col" class="manage-column">Emails</th>
                        <th scope="col" class="manage-column">Action</th>
                    </tr>
                </thead>
                <tbody id="email-tunnel-connection-table-body">
                </tbody>
                <tfoot>
                    <tr>
                        <th scope="col" class="manage-column column-primary">Entrance</th>
                        <th scope="col" class="manage-column">Exit</th>
                        <th scope="col" class="manage-column">Emails</th>
                        <th scope="col" class="manage-column">Action</th>
                    </tr>
                </tfoot>
            </table>
        `;
    });

    test('should contain a button in the Action column that calls doCollapseTunnel with URLs', () => {
        const statusArray = [
            { "title": "https://sitea.com", "status": "entrance", "exit-site": "https://siteexit.com", "email-count": "100" }
        ];

        const table = document.getElementById('email-tunnel-connection-table');
        fillConnectionTableWithData(table, statusArray);

        const rows = table.querySelectorAll('tbody tr');
        expect(rows.length).toBe(1);

        const actionButton = rows[0].cells[3].querySelector('button');
        expect(actionButton).not.toBeNull();
        expect(actionButton.textContent).toBe("Collapse Tunnel");

        // Check if the onclick attribute calls the right function with correct arguments
        expect(actionButton.getAttribute('onclick')).toBe(`doCollapseTunnel('${statusArray[0].title}', '${statusArray[0]['exit-site']}')`);
    });
});